Constants
=========

These constants are used throughout Yuio whenever :data:`None` is too ambiguous.

.. autodata:: yuio.DISABLED

.. autodata:: yuio.MISSING

.. autodata:: yuio.POSITIONAL

.. autodata:: yuio.GROUP
